#
# spec file for package meep
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define somajor 12
Name:           meep
Version:        1.7.0
Release:        1.2
Summary:        FDTD finite-difference time-domain solver
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
Url:            http://ab-initio.mit.edu/wiki/index.php/Meep
Source0:        https://github.com/stevengj/meep/releases/download/v%{version}/meep-%{version}.tar.gz
# proposed to upstream: https://github.com/stevengj/meep/pull/618
Patch0:         namespace-for-complex-literals.patch
BuildRequires:  binutils
BuildRequires:  blas-devel
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gmp-devel
BuildRequires:  gsl-devel
BuildRequires:  guile-devel
BuildRequires:  harminv-devel
BuildRequires:  hdf5-devel
BuildRequires:  lapack-devel
BuildRequires:  latex2html
BuildRequires:  libctl-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel

# providing ice-9/boot-9.scm
Requires:       guile

# providing /usr/share/libctl/base/include.scm
Requires:       libctl-devel

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Meep (or MEEP) is a free finite-difference time-domain (FDTD)
simulation software package developed at MIT to model electromagnetic
systems.

%package -n     lib%{name}%{somajor}
Summary:        FDTD finite-difference time-domain solver library
# Avoid unresolvable errors from multiple providers
Group:          System/Libraries
Requires:       libhdf5

%description -n lib%{name}%{somajor}
Meep (or MEEP) is a free finite-difference time-domain (FDTD)
simulation software package developed at MIT to model electromagnetic
systems.

%package -n     libmeepgeom%{somajor}
Summary:        C++ library for meep geometries
Group:          System/Libraries

%description -n libmeepgeom%{somajor}
Libmeepgeom provides a C++ library to specify Meep geometries in terms
of a list of geometric objects (spheres, cylinders, boxes) with 
various material properties.

%package        devel
Summary:        Libraries and header files for meep library
Group:          Development/Libraries/Other
Requires:       lib%{name}%{somajor} = %{version}
Requires:       libmeepgeom%{somajor} = %{version}

%description    devel
Meep (or MEEP) is a free finite-difference time-domain (FDTD)
simulation software package developed at MIT to model electromagnetic
systems.

This package contains libraries and header files for developing
applications that use meep.

%prep
%setup -q
%patch0 -p1

%build
export CFLAGS="%{optflags} -fPIC"
export CXXFLAGS="%{optflags} -fPIC -std=c++14"
export FFLAGS="%{optflags} -fPIC"
%configure --enable-shared --disable-static --enable-portable-binary
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
make check

%post -n lib%{name}%{somajor} -p /sbin/ldconfig
%post -n libmeepgeom%{somajor} -p /sbin/ldconfig

%postun -n lib%{name}%{somajor} -p /sbin/ldconfig
%postun -n libmeepgeom%{somajor} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYRIGHT NEWS.md
%{_bindir}/*
%{_datadir}/meep/

%files -n lib%{name}%{somajor}
%defattr(-,root,root)
%{_libdir}/libmeep.so.*

%files -n libmeepgeom%{somajor}
%defattr(-,root,root)
%{_libdir}/libmeepgeom.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/libmeep.so
%{_libdir}/libmeepgeom.so
%{_libdir}/pkgconfig/*
%{_includedir}/*

%changelog
* Thu Nov 22 2018 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.7.0:
  * See /usr/share/meep/NEWS.md
- update so version to 12
- add patch:
  * namespace-for-complex-literals.patch: fixes build failure
- drop patch:
  * meep_change_protos_with_harminv_complex.patch
- add libmeepgeom library
- correct doc file names
- use c++14 for complex_literals
* Fri Jan 20 2017 wagner-thomas@gmx.at
- added two requirements to make meep start
* Mon Aug 31 2015 toddrme2178@gmail.com
- Avoid unresolvable errors from multiple providers of libhdf5
* Wed Feb 25 2015 normand@linux.vnet.ibm.com
- new patch meep_change_protos_with_harminv_complex.patch
  required for ppc64 architecture to avoid make check error
  while building meep package.
* Sun Jan 25 2015 dmitry_r@opensuse.org
- Update to version 1.2.1
  * See included NEWS file for details
- Move library to separate package according to SLPP
- Enable post-build testing
* Tue Aug 21 2012 scorot@free.fr
- Buildrequires libguile1 on recent product
* Fri May 11 2012 scorot@free.fr
- remove conditional BuildRequires for blas and lapack since
  recent lapack now build correctly for all suse version
* Sat Apr 14 2012 badshah400@gmail.com
- Update BuildRequires in keeping with lapack package naming
  changes
- Spec file cleanups
- Modify License tag in confomity with spdx.org specifications.
